Coverage report

File |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | ---
src / remedapy / __init__.py |  | 28 | 0 | 0 |  | 100%
src / remedapy / add.py |  | 7 | 0 | 15 |  | 100%
src / remedapy / all_pass.py |  | 12 | 0 | 8 |  | 100%
src / remedapy / any_pass.py |  | 12 | 0 | 8 |  | 100%
src / remedapy / capitalise.py |  | 8 | 1 | 8 |  | 88%
src / remedapy / decorator.py |  | 13 | 0 | 0 |  | 100%
src / remedapy / default_to.py |  | 11 | 0 | 8 |  | 100%
src / remedapy / difference.py |  | 14 | 0 | 15 |  | 100%
src / remedapy / difference_with.py |  | 13 | 0 | 17 |  | 100%
src / remedapy / ends_with.py |  | 6 | 0 | 8 |  | 100%
src / remedapy / filter.py |  | 25 | 8 | 24 |  | 68%
src / remedapy / find.py |  | 10 | 0 | 8 |  | 100%
src / remedapy / find_index.py |  | 10 | 1 | 8 |  | 90%
src / remedapy / local_types.py |  | 1 | 0 | 0 |  | 100%
src / remedapy / map.py |  | 26 | 5 | 24 |  | 81%
src / remedapy / multiply.py |  | 7 | 1 | 15 |  | 86%
src / remedapy / only.py |  | 7 | 0 | 8 |  | 100%
src / remedapy / pipe.py |  | 23 | 0 | 210 |  | 100%
src / remedapy / piped.py |  | 21 | 0 | 198 |  | 100%
src / remedapy / prop.py |  | 18 | 5 | 28 |  | 72%
src / remedapy / random_string.py |  | 9 | 0 | 8 |  | 100%
src / remedapy / range.py |  | 10 | 0 | 8 |  | 100%
src / remedapy / reduce.py |  | 15 | 0 | 8 |  | 100%
src / remedapy / splice.py |  | 15 | 0 | 8 |  | 100%
src / remedapy / starts_with.py |  | 6 | 0 | 8 |  | 100%
src / remedapy / subtract.py |  | 7 | 0 | 15 |  | 100%
src / remedapy / take.py |  | 10 | 0 | 8 |  | 100%
src / remedapy / tap.py |  | 8 | 0 | 8 |  | 100%
src / remedapy / uncapitalise.py |  | 8 | 1 | 8 |  | 88%
src / remedapy / unique.py |  | 11 | 0 | 8 |  | 100%
src / tests / test_add.py |  | 9 | 0 | 0 |  | 100%
src / tests / test_all_pass.py |  | 12 | 0 | 0 |  | 100%
src / tests / test_any_pass.py |  | 12 | 0 | 0 |  | 100%
src / tests / test_capitalise.py |  | 6 | 0 | 0 |  | 100%
src / tests / test_default_to.py |  | 8 | 0 | 0 |  | 100%
src / tests / test_difference.py |  | 8 | 0 | 0 |  | 100%
src / tests / test_difference_with.py |  | 8 | 0 | 0 |  | 100%
src / tests / test_ends_with.py |  | 8 | 0 | 0 |  | 100%
src / tests / test_filter.py |  | 8 | 0 | 0 |  | 100%
src / tests / test_find.py |  | 11 | 0 | 0 |  | 100%
src / tests / test_find_index.py |  | 11 | 0 | 0 |  | 100%
src / tests / test_lazy_evaluation.py |  | 6 | 0 | 0 |  | 100%
src / tests / test_map.py |  | 15 | 0 | 0 |  | 100%
src / tests / test_only.py |  | 11 | 0 | 0 |  | 100%
src / tests / test_piped.py |  | 4 | 0 | 0 |  | 100%
src / tests / test_random_string.py |  | 10 | 0 | 0 |  | 100%
src / tests / test_range.py |  | 7 | 0 | 0 |  | 100%
src / tests / test_reduce.py |  | 7 | 0 | 0 |  | 100%
src / tests / test_splice.py |  | 11 | 0 | 0 |  | 100%
src / tests / test_starts_with.py |  | 8 | 0 | 0 |  | 100%
src / tests / test_subtract.py |  | 10 | 0 | 0 |  | 100%
src / tests / test_take.py |  | 6 | 0 | 0 |  | 100%
src / tests / test_tap.py |  | 15 | 0 | 0 |  | 100%
src / tests / test_uncapitalise.py |  | 6 | 0 | 0 |  | 100%
src / tests / test_unique.py |  | 4 | 0 | 0 |  | 100%
src / tests / util.py |  | 6 | 0 | 0 |  | 100%
Total |  | 598 | 22 | 697 |  | 96%

No items found using the specified filter.